@@ -30,6 +30,8 @@ translation messages and the core :xfile:`help_texts.py` file.
 # from __future__ import absolute_import
 # from builtins import str
 
+import setuptools # avoid UserWarning "Distutils was imported before Setuptools"?
+
 import sys
 import os
 from os.path import join, dirname
@@ -54,6 +56,14 @@ warnings.filterwarnings(
     "error", "DateTimeField .* received a naive datetime (.*) while time zone support is active.",
     RuntimeWarning, "django.db.models.fields")
 
+# doesn't work here because that's too late:
+# warnings.filterwarnings(
+#     "ignore", "Distutils was imported before Setuptools. This usage is discouraged and may exhibit undesirable behaviors or errors. Please use Setuptools' objects directly or at least import Setuptools first.",
+#     UserWarning, "setuptools.distutils_patch")
+
+# TODO: get everything to work even when ResourceWarning gives an error
+# warnings.filterwarnings("error", category=ResourceWarning)
+
 from django.conf import settings
 from django.apps import AppConfig
 
