@@ -16,17 +16,14 @@ from django.utils.encoding import force_text
 from django.conf import settings
 from django.db import models
 
-from django.apps import apps
-
-get_models = apps.get_models
+from django.apps import apps ; get_models = apps.get_models
 
 from lino.core import constants
 from lino.core import layouts
 from lino.core import fields
 from lino.core import keyboard
 from lino.modlib.users.utils import get_user_profile
-from lino.utils.choosers import Chooser
-from lino.core.fields import set_default_verbose_name
+from lino.utils.choosers import check_for_chooser
 
 from .permissions import Permittable
 from .utils import obj2unicode
@@ -35,26 +32,6 @@ from .utils import navinfo
 from .utils import Parametrizable
 from .requests import InstanceAction
 
-
-def check_for_chooser(holder, field):
-    # holder is either a Model, an Actor or an Action.
-    if isinstance(field, fields.DummyField):
-        return
-    methname = field.name + "_choices"
-    m = getattr(holder, methname, None)
-    if m is not None:
-        ch = Chooser(holder, field, m)
-        d = holder.__dict__.get('_choosers_dict', None)
-        if d is None:
-            d = dict()
-            setattr(holder, '_choosers_dict', d)
-        if ch in d:
-            raise Exception("Redefinition of chooser %s" % field)
-        d[field.name] = ch
-    # if field.name == 'city':
-    #     logger.info("20140822 chooser for %s.%s", holder, field.name)
-
-
 def discover_choosers():
     logger.debug("Discovering choosers for model fields...")
     # ~ logger.debug("Instantiate model reports...")
@@ -69,7 +46,7 @@ def discover_choosers():
 def install_layout(cls, k, layout_class, **options):
     """
     - `cls` is the actor (a class object)
-    - `k` is one of 'detail_layout', 'insert_layout', 'params_layout'
+    - `k` is one of 'detail_layout', 'insert_layout', 'params_layout', 'card_layout'
     - `layout_class`
 
     """
@@ -77,7 +54,7 @@ def install_layout(cls, k, layout_class, **options):
     #     print("20160329 install_layout", k, layout_class)
     dl = cls.__dict__.get(k, None)
     if dl is None:  # and not cls._class_init_done:
-        dl = getattr(cls, k)
+        dl = getattr(cls, k, None)
     if dl is None:
         return
     if isinstance(dl, str):
@@ -138,7 +115,7 @@ def setup_params_choosers(self):
                 msg = "Invalid target %s in parameter {} of {}".format(
                     k, self)
                 fld.remote_field.model = resolve_model(fld.remote_field.model, strict=msg)
-                set_default_verbose_name(fld)
+                fields.set_default_verbose_name(fld)
 
             check_for_chooser(self, fld)
 
@@ -507,7 +484,7 @@ class Action(Parametrizable, Permittable):
     hide_virtual_fields = False
     required_states = None
 
-    def __init__(self, label=None, **kw):
+    def __init__(self, label=None, **kwargs):
         if label is not None:
             self.label = label
 
@@ -515,7 +492,7 @@ class Action(Parametrizable, Permittable):
         #     self.show_in_bbar = False
         #     # see ticket #105
 
-        for k, v in list(kw.items()):
+        for k, v in kwargs.items():
             if not hasattr(self, k):
                 raise Exception("Invalid action keyword %s" % k)
             setattr(self, k, v)
@@ -540,6 +517,20 @@ class Action(Parametrizable, Permittable):
         return InstanceAction(
             self, instance.get_default_table(), instance, owner)
 
+    def get_django_form(self):
+        """returns a django form object based on the params of this action"""
+        from django import forms
+
+        mapping = {
+            "PasswordField":"CharField"
+        }
+
+        class LinoForm(forms.Form):
+            pass
+        for name,field in self.parameters.items():
+            setattr(LinoForm, name, getattr(forms, mapping.get(field.__class__.__name__,field.__class__.__name__))())
+        return LinoForm
+
     @classmethod
     def decorate(cls, *args, **kw):
         """
@@ -1310,7 +1301,7 @@ class DeleteSelected(MultipleRowAction):
         else:
             d.update(type=ar.actor.model._meta.verbose_name_plural)
         msg = gettext("You are about to delete %(num)d %(type)s:\n%(targets)s") % d
-        ar.confirm(ok, u"{}\n{}".format(msg, gettext("Are you sure ?")),
+        ar.confirm(ok, "{}\n{}".format(msg, gettext("Are you sure ?")),
                    uid="deleting %(num)d %(type)s pks=" % d + "".join([str(t.pk) for t in ar.selected_rows]))
 
     def run_on_row(self, obj, ar):
