@@ -518,6 +518,30 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
     :class:`lino_xl.cal.CalenderView`.
 
     """
+
+    simple_slavegrid_header = False
+    """
+    If True the slave grid in a detail will be simplified
+    """
+
+    # paginator_rowsPerPageOptions = None
+    # """Array of integer values to display inside rows per page dropdown in the paginator."""
+
+    paginator_template = None
+    """
+    Paginator elements can be customized using the template property using the predefined keys, default value is
+    "FirstPageLink PrevPageLink PageLinks NextPageLink LastPageLink RowsPerPageDropdown".
+    Here are the available elements that can be placed inside a paginator.
+
+    FirstPageLink
+    PrevPageLink
+    PageLinks
+    NextPageLink
+    LastPageLink
+    RowsPerPageDropdown
+    CurrentPageReport
+    """
+
     _label = None
     _editable = None
     _known_values = {}
@@ -604,6 +628,10 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
     and name) and it makes no sense to have an insert window.
     """
 
+    card_layout = None
+    """
+    Define a layout for a card view of the table."""
+
     detail_template = None    # deprecated: use insert_layout instead
     insert_template = None    # deprecated: use detail_layout instead
 
@@ -730,6 +758,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
         if issubclass(model, models.Model):
             try:
                 return model.get_user_queryset(ar.get_user()).get(pk=pk)
+                # why not simply return model.objects.get(pk=pk) ?
             except ValueError:
                 return None
             except model.DoesNotExist:
@@ -916,7 +945,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
         cls.collect_virtual_fields()
 
         # set the verbose_name of the detail_link field
-        model = cls.model
+        # model = cls.model
         if isinstance(model, type) and issubclass(model, models.Model):
             de = cls.detail_link
             assert de.model is not None
@@ -931,18 +960,31 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
                     cls.virtual_fields['detail_link'] = de
                     # cls.add_virtual_field('detail_link', de)
 
-        actions.install_layout(cls, 'detail_layout', layouts.DetailLayout)
-        actions.install_layout(
-            cls, 'insert_layout', layouts.InsertLayout,
-            window_size=(cls.insert_layout_width, 'auto'))
+    @classmethod
+    def init_layouts(cls):
 
-        if cls.parameters is None:
+        # 20200430 this was previously part of class_init, but is now called in
+        # a second loop. Because calview.EventsParams copies parameters from Events.
+
+        actions.install_layout(cls, 'detail_layout', layouts.DetailLayout)
+        actions.install_layout(cls, 'insert_layout', layouts.InsertLayout,
+            window_size=(cls.insert_layout_width, 'auto'))
+        actions.install_layout(cls, 'card_layout', layouts.DetailLayout,
+            # window_size=(cls.card_layout_width, 'auto')
+        )
+
+        if cls.abstract:
+            return
+
+        if 'parameters' in cls.__dict__:
+            cls.setup_parameters(cls.parameters)
+        else:
             params = {}
+            if cls.parameters is not None:
+                params.update(cls.parameters)
             cls.setup_parameters(params)
             if len(params):
                 cls.parameters = params
-        else:
-            cls.setup_parameters(cls.parameters)
 
         lst = []
         for n in cls.get_simple_parameters():
@@ -960,8 +1002,10 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
             if name not in cls.parameters:
                 db_field = cls.get_data_elem(name)
                 if db_field is None:
-                    raise Exception("get_simple_parameters() returned invalid name '{}'".format(name))
+                    raise Exception("{}.get_simple_parameters() returned invalid name '{}'".format(cls, name))
                 cls.parameters[name] = dbfield2params_field(db_field)
+                # if "__" in name:
+                #     print("20200423", cls.parameters)
         # if len(cls.parameters) == 0:
         #     cls.parameters = None # backwards compatibility
 
@@ -1040,9 +1084,9 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
     def _collect_actions(cls):
         """
         Loops through the class dict and collects all Action instances,
-        calling `_attach_action` which will set their `actor` attribute.
+        calling :meth:`_attach_action`, which will set their `actor` attribute.
         Before this we create `insert_action` and `detail_action` if necessary.
-        Also fill _actions_list.
+        Also fill :attr:`_actions_list`.
         """
 
         default_action = cls.get_default_action()
@@ -1207,6 +1251,14 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
         """
         return str(obj)
 
+    @classmethod
+    def get_card_title(self, ar, obj):
+        return self.get_detail_title(ar, obj)
+
+    @classmethod
+    def get_main_card(self, ar,):
+        return None
+
     @classmethod
     def get_choices_text(self, obj, request, field):
         """
@@ -1302,7 +1354,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
         if cls.model is None:
             return
         if not isinstance(cls.model, type):
-            raise Exception("{}.model is not a class".format(cls))
+            raise Exception("{}.model is {!r} (must be a class)".format(cls, cls.model))
         if issubclass(cls.model, fields.TableRow):
             cls.model.setup_parameters(params)
 
