@@ -1,11 +1,8 @@
-# Copyright 2009-2016 Rumma & Ko Ltd
+# Copyright 2009-2020 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 """Defines explicit code names for URL parameters
 
 """
-# import six
-# str = six.text_type
-from builtins import str
 
 _handle_attr_name = '_lino_ui_handle'
 
@@ -14,6 +11,8 @@ CHOICES_TEXT_FIELD = 'text'
 CHOICES_VALUE_FIELD = 'value'
 CHOICES_HIDDEN_SUFFIX = "Hidden"
 
+CHOICES_BLANK_FILTER_VALUE = "<BLANK>"
+CHOICES_NOT_BLANK_FILTER_VALUE ="<!BLANK>"
 
 URL_PARAM_PROJECT = 'prj'
 URL_PARAM_TEAM_VIEW = 'tv'
@@ -45,6 +44,14 @@ URL_PARAM_USER_LANGUAGE = 'ul'
 override user language
 """
 
+URL_PARAM_WINDOW_TYPE = 'wt'
+
+WINDOW_TYPE_TABLE = "t"
+WINDOW_TYPE_DETAIL = "d"
+WINDOW_TYPE_INSERT = "i"
+WINDOW_TYPE_CARDS = "c"
+WINDOW_TYPE_PV = "p"
+
 
 #~ URL_PARAM_EUSER = 'euser'
 #~ URL_PARAM_EUSER = 'su'
