@@ -4,8 +4,6 @@
 """
 This defines the :class:`Table` class.
 """
-import six
-# str = six.text_type
 
 import logging ; logger = logging.getLogger(__name__)
 
@@ -24,6 +22,7 @@ from lino.core import fields
 from lino.core import actions
 from lino.core.model import Model
 from lino.core import actors
+from lino.core import constants
 
 from lino.core.choicelists import ChoiceListField
 from .utils import models_by_base
@@ -353,12 +352,12 @@ class Table(AbstractTable):
             self.model = None
 
         if self.model is not None:
-            if isinstance(self.hidden_columns, six.string_types):
+            if isinstance(self.hidden_columns, str):
                 self.hidden_columns = frozenset(
                     fields.fields_list(self.model, self.hidden_columns))
             self.hidden_columns |= self.model.hidden_columns
 
-            if isinstance(self.active_fields, six.string_types):
+            if isinstance(self.active_fields, str):
                 self.active_fields = frozenset(
                     fields.fields_list(self.model, self.active_fields))
             self.active_fields |= self.model.active_fields
@@ -594,12 +593,21 @@ class Table(AbstractTable):
                 qs = qs.exclude(**ar.exclude)
                 # qs = qs.exclude(ar.exclude)
 
+            # 20200425
             spv = dict()
             for k in self.simple_parameters:
                 v = getattr(ar.param_values, k)
-                if v is not None:
+                # if "room" in k:
+                # print("20200423", k, v, self.simple_parameters, ar.param_values)
+                if v == constants.CHOICES_BLANK_FILTER_VALUE:
+                    spv[k+"__isnull"] = True
+                elif v == constants.CHOICES_NOT_BLANK_FILTER_VALUE:
+                    spv[k+"__isnull"] = False
+                elif v is not None:
                     spv[k] = v
+
             qs = self.model.add_param_filter(qs, **spv)
+            # qs = self.model.add_param_filter(qs, **ar.param_values)
 
             if self.filter:
                 qs = qs.filter(self.filter)
