@@ -20,10 +20,12 @@ from django.utils.functional import cached_property
 
 from lino.core.utils import resolve_field, full_model_name, resolve_model
 from lino.core.exceptions import ChangedAPI
+from lino.core.diff import ChangeWatcher
 
 from lino.utils import get_class_attr
 from lino.utils import IncompleteDate
 from lino.utils import quantities
+from lino.utils import choosers
 from lino.utils.quantities import Duration
 
 
@@ -219,6 +221,7 @@ class FakeField(object):
     default = NOT_PROVIDED
     generate_reverse_relation = False  # needed when AFTER17
     remote_field = None
+    blank = True  # 20200425
 
     wildcard_data_elem = False
     """Whether to consider this field as wildcard data element.
@@ -284,7 +287,7 @@ class RemoteField(FakeField):
 
     .. attribute:: field
 
-        The bottom-level field object.
+        The bottom-level (leaf) field object.
 
     """
     #~ primary_key = False
@@ -294,10 +297,16 @@ class RemoteField(FakeField):
         self.func = getter
         self.name = name
         self.attname = name
+        # self.db_column = name  # 20200423
         self.field = fld
+        # for k in ('verbose_name', 'help_text', 'blank', 'default', 'null'):
+        #     kwargs.setdefault(k, getattr(fld, k))
         self.verbose_name = fld.verbose_name
         self.help_text = fld.help_text
-        self.blank = fld.blank
+        # self.blank = fld.blank
+        self.blank = True
+        self.default = None
+        # self.null = fld.null
         # self.null = getattr(fld, 'null', None)
         self.max_length = getattr(fld, 'max_length', None)
         self.max_digits = getattr(fld, 'max_digits', None)
@@ -312,8 +321,20 @@ class RemoteField(FakeField):
         #~ print 20120424, self.name
         #~ settings.SITE.register_virtual_field(self)
 
-        if isinstance(fld, models.ForeignKey) or (isinstance(fld, VirtualField) and isinstance(fld.return_type, models.ForeignKey)):
-            self.remote_field = self.field.remote_field
+        # The remote_field of a FK field has nothing to do with our RemoteField,
+        # it is set by Django on each FK field and points to
+
+        if isinstance(fld, VirtualField) and isinstance(fld.return_type, models.ForeignKey):
+            fld.lino_resolve_type()  # 20200425
+            fk = fld.return_type
+        elif isinstance(fld, models.ForeignKey):
+            fk = fld
+        else:
+            fk = None
+        if fk is not None:
+            # if not fk.remote_field:
+            #     raise Exception("20200425 {} has no remote_field".format(fk))
+            self.remote_field = fk.remote_field
             from lino.core import store
             store.get_atomizer(self.remote_field, self, name)
 
@@ -344,7 +365,7 @@ class DisplayField(FakeField):
     translatable text or a :mod:`HTML element <etgen.html>`.
     """
     choices = None
-    blank = True
+    blank = True  # 20200425
     drop_zone = None
     max_length = None
 
@@ -356,8 +377,9 @@ class DisplayField(FakeField):
     # using a DisplayField as return_type of a VirtualField
 
     def to_python(self, *args, **kw):
-        raise NotImplementedError(
-            "%s.to_python(%s,%s)", (self.name, args, kw))
+        return None
+        # raise NotImplementedError(
+        #     "{}.to_python({},{})".format(self.name, args, kw))
 
     def save_form_data(self, *args, **kw):
         raise NotImplementedError
@@ -400,6 +422,11 @@ class HtmlBox(DisplayField):
 #     def __repr__(self):
 #         return "<{0}>.{1}".format(repr(self.instance), self.vf.name)
 
+class VirtualModel:
+    def __init__(self, model):
+        self.wrapped_model = model
+        self._meta = model._meta
+
 VFIELD_ATTRIBS = frozenset('''to_python choices save_form_data
   value_to_string max_length remote_field
   max_digits verbose_name decimal_places
@@ -474,6 +501,9 @@ class VirtualField(FakeField):
         if isinstance(f, models.ForeignKey):
             f.remote_field.model = resolve_model(f.remote_field.model)
             set_default_verbose_name(f)
+            self.get_lookup = f.remote_field.get_lookup  # 20200425
+            self.get_path_info = f.remote_field.get_path_info  # 20200425
+            self.remote_field = f.remote_field
 
         for k in VFIELD_ATTRIBS:
             setattr(self, k, getattr(f, k, None))
@@ -490,8 +520,6 @@ class VirtualField(FakeField):
         from lino.core import store
         store.get_atomizer(self.model, self, self.name)
 
-
-
         # print("20181023 Done: lino_resolve_type() for {}".format(self))
 
 
@@ -502,6 +530,11 @@ class VirtualField(FakeField):
         self.model = model
         self.name = name
         self.attname = name
+        if hasattr(self.return_type, 'model'):
+            # logger.info("20200425 return_type for virtual field %s has a model", self)
+            return
+        self.return_type.model = VirtualModel(model)
+        self.return_type.column = None
 
         # if name == "overview":
         #     print("20181022", self, self.verbose_name)
@@ -1014,11 +1047,13 @@ class TableRow(object):
 
     @classmethod
     def setup_parameters(cls, params):
-        """Inheritable hook for defining parameters.
+        """Inheritable hook for defining parameters for every actor on this model.
+
         Called at site startup once for each actor using this model.
 
-        It receives a `dict` object `params` and is alloed to update that
-        `dict`, which will be used to fill the actor's `parameters`.
+        Toes not return anything. Receives a `dict` object `params` and is
+        expected to update that `dict`, which will be used to fill the actor's
+        :attr:`parameters`.
 
         See also :meth:`get_simple_parameters`.
 
@@ -1147,6 +1182,12 @@ class TableRow(object):
         # return [ar.obj2html(self)]
         return [self.obj2href(ar)]
 
+    def save_existing_instance(self, ar):
+        watcher = ChangeWatcher(self)
+        ar.ah.store.form2obj(ar, ar.rqdata, self, False)
+        self.full_clean()
+        self.save_watched_instance(ar, watcher)
+
 
 def wildcard_data_elems(model):
     """
@@ -1249,50 +1290,6 @@ def pointer_factory(cls, othermodel, *args, **kw):
     return cls(othermodel, *args, **kw)
 
 
-
-def unused_get_data_elem_from_model(cls, name):
-
-    """
-
-    Return the named data element from model if it exists. This can be a
-    database field, a :class:`lino.core.fields.RemoteField`, a
-    :class:`lino.core.fields.VirtualField` or a Django-style virtual field
-    (GenericForeignKey).
-
-    Works for edge cases like ContentType (which is a pure Django model) or
-    lino_xl.lib.cal.Day (which is not a Django model at all)
-
-    """
-    #~ logger.info("20120202 get_data_elem %r,%r",model,name)
-
-    for m in cls.mro():  # __mro__:
-        if issubclass(m, models.Model):
-
-            if not name.startswith('__'):
-                rf = make_remote_field(cls, name)
-                if rf:
-                    return rf
-            try:
-                return cls._meta.get_field(name)
-            except models.FieldDoesNotExist:
-                pass
-
-            for vf in cls._meta.private_fields:
-                if vf.name == name:
-                    return vf
-
-        elif issubclass(m, TableRow):
-
-            de = m.get_data_elem(name)
-            if de is not None:
-                return de
-
-        de = getattr(m, name, None)
-        if de is not None:
-            return de
-
-    # return get_class_attr(cls, name)
-
 def make_remote_field(model, name):
     parts = name.split('__')
     if len(parts) == 1:
@@ -1304,10 +1301,12 @@ def make_remote_field(model, name):
     cls = model
     field_chain = []
     editable = False
+    leaf_chooser = None
     for n in parts:
         if model is None:
-            raise Exception(
-                "Invalid remote field {0} for {1}".format(name, cls))
+            return
+            # raise Exception(
+            #     "Invalid remote field {0} for {1}".format(name, cls))
 
         if isinstance(model, str):
             # Django 1.9 no longer resolves the
@@ -1318,22 +1317,30 @@ def make_remote_field(model, name):
 
         fld = model.get_data_elem(n)
         if fld is None:
-            raise Exception(
-                "Invalid RemoteField %s.%s (no field %s in %s)" %
-                (full_model_name(model), name, n, full_model_name(model)))
+            return
+            # raise Exception(
+            #     "Invalid RemoteField %s.%s (no field %s in %s)" %
+            #     (full_model_name(model), name, n, full_model_name(model)))
+
         # make sure that the atomizer gets created.
         store.get_atomizer(model, fld, fld.name)
+
+        if isinstance(fld, VirtualField):
+            fld.lino_resolve_type()
+        leaf_chooser = choosers.check_for_chooser(model, fld)
+
         field_chain.append(fld)
         if isinstance(fld, models.OneToOneRel):
             editable = True
         if getattr(fld, 'remote_field', None):
             model = fld.remote_field.model
-        elif getattr(fld, 'rel', None):
-            raise Exception("20180712")
-            model = fld.rel.model
         else:
             model = None
 
+    if leaf_chooser is not None:
+        d = choosers.get_choosers_dict(cls)
+        d[name] = leaf_chooser
+
     def getter(obj, ar=None):
         try:
             for fld in field_chain:
@@ -1354,7 +1361,9 @@ def make_remote_field(model, name):
             return None
 
     if not editable:
-        return RemoteField(getter, name, fld)
+        rf = RemoteField(getter, name, fld)
+        # choosers.check_for_chooser(model, rf)
+        return rf
 
     def setter(obj, value):
         # logger.info("20180712 %s setter() %s", name, value)
@@ -1397,4 +1406,13 @@ def make_remote_field(model, name):
                 return str(e)
             return False
 
-    return RemoteField(getter, name, fld, setter)
+    rf = RemoteField(getter, name, fld, setter)
+    # choosers.check_for_chooser(model, rf)
+    return rf
+
+# # would be nice for lino_xl.lib.vat.VatItemBase.item_total
+# class FieldAlias(VirtualField):
+#     def __init__(self, orig_name):
+#         ...
+#
+#
