@@ -343,12 +343,6 @@ class Kernel(object):
                         "{} field {}.{} hidden by virtual field of same name.".format(
                             f.__class__.__name__, fmn(model), k))
 
-
-
-
-        # Protect the foreign keys by removing Django's default
-        # behaviour of having on_delete with CASCADE as default.
-
         self.protect_foreignkeys(models_list)
 
         if site.workflows_module:
@@ -383,6 +377,14 @@ class Kernel(object):
         for model in models_list:
             model.collect_virtual_fields()
 
+        # after injecting a field to a model, we must also reload the field
+        # cache for all MTI childern of that model. This can't be done by
+        # inject_field() because when inject_field() runs, the full list of
+        # models is not yet known.  So we do it now.  After this point we must
+        # not inject more fields.
+        for model in models_list:
+            model._meta._expire_cache()
+
         # for vt in virtual_tables:
         #     if vt.model is not None:
         #         assert vt.model._lino_default_table is None
@@ -414,12 +416,16 @@ class Kernel(object):
 
         logger.debug("actors.initialize()")
         for a in actors.actors_list:
-            # a.class_init()
-            try:
-                a.class_init()
-            except Exception as e:
-                logger.error("Failed to initialize actor %s : %s", a, e)
-                raise # Exception("Failed to class_init {} : {}".format(a, e))
+            a.class_init()
+            # try:
+            #     a.class_init()
+            # except Exception as e:
+            #     logger.error("Failed to initialize actor %s : %s", a, e)
+            #     raise # Exception("Failed to class_init {} : {}".format(a, e))
+
+
+        for a in actors.actors_list:
+            a.init_layouts()
 
         register_actors()
 
@@ -440,6 +446,7 @@ class Kernel(object):
                 # print ("20170104 No table for {}, created default table.".format(model))
                 register_model_table(rpt)
                 rpt.class_init()
+                rpt.init_layouts()
                 # rpt.collect_actions()
                 model._lino_default_table = rpt
 
@@ -560,7 +567,8 @@ class Kernel(object):
 
         for p in self.site.installed_plugins:
             if p.app_name == self.site.default_ui:
-                p.url_prefix = None
+                if not p.force_url_prefix:
+                    p.url_prefix = None
                 self.default_renderer = p.renderer
                 self.default_ui = p
                 self.html_renderer = HtmlRenderer(p)
@@ -614,6 +622,9 @@ class Kernel(object):
         """Change `on_delete` from CASCADE (Django's default value) to PROTECT
         for foreignkeys that need to be protected.
 
+        Protect the foreign keys by removing Django's default
+        behaviour of having on_delete with CASCADE as default.
+
         Basically we protect all FK fields that are not listed in
         their model's :attr:`allow_cascaded_delete
         <lino.core.model.Model.allow_cascaded_delete>`. With one
@@ -622,6 +633,10 @@ class Kernel(object):
         become protected (because Lino handles it automatically, see
         :meth:`lino.mixins.polymorphic.Polymorphic.disable_delete`).
 
+        Note that this does not protect FK fields that get defined afterwards,
+        e.g. during pre_analyze, e.g. the purchase_account field defined by
+        TradeTypes.purchases in ledger.
+
         """
 
         from lino.mixins.polymorphic import Polymorphic
@@ -649,7 +664,7 @@ class Kernel(object):
                         #     "Setting {0}.{1}.on_delete to PROTECT because "
                         #     "field is not specified in "
                         #     "allow_cascaded_delete.").format(fmn(m), fk.name)
-                        # logger.debug(msg)
+                        # logger.info(msg)
                         fk.remote_field.on_delete = models.PROTECT
                 else:
                     if fk.name in m.allow_cascaded_delete:
