@@ -105,10 +105,11 @@ class LayoutHandle(object):
         self._names = {}
 
         # self.define_panel('main', layout.main)
-        if settings.SITE.mobile_view:
-            main = layout.main_m or layout.main
-        else:
-            main = layout.main
+        # if settings.SITE.mobile_view:
+        #     main = layout.main_m or layout.main
+        # else:
+        #     main = layout.main
+        main = layout.main
         self.define_panel('main', main)
 
         self.main = self._names.get('main')
@@ -421,11 +422,11 @@ class BaseLayout(object):
 
     """
 
-    main_m = None
-    """An optional alternative for :attr:`main` to use when
-    :attr:`mobile_view <lino.core.site.Site.mobile_view>` is True.
-
-    """
+    # main_m = None
+    # """An optional alternative for :attr:`main` to use when
+    # :attr:`mobile_view <lino.core.site.Site.mobile_view>` is True.
+    #
+    # """
 
     def __init__(self, main=None, datasource=None,
                  hidden_elements=None, **kw):
@@ -716,6 +717,9 @@ class ParamsLayout(BaseLayout):
         de = self._datasource.get_param_elem(name)
         if de is None:
             de = self._datasource.get_data_elem(name)
+        de.editable = True  # 20200425
+        # if "__" in name:
+        #     print("20200425 ParamsLayout.get_data_elem()", name, de)
         return de
 
     def setup_handle(self, lh):
