@@ -12,7 +12,7 @@ from django.conf import settings
 from django.core.exceptions import ValidationError
 from django.utils.translation import ugettext_lazy as _
 
-from etgen.html import E, forcetext
+from etgen.html import E, forcetext, tostring
 
 from lino.core import fields
 from lino.core import signals
@@ -106,11 +106,11 @@ class Model(models.Model, fields.TableRow):
 
         For every field named "FOO" for which a chooser exists, if the model
         also has a method called "create_FOO_choice", then this chooser will be
-        a "learning" chooser. That is, users can enter text into the combobox,
-        and Lino will create a new database object from it.
+        a :term:`learning chooser`. That is, users can enter text into the
+        combobox, and Lino will create a new database object from it.
 
         This works only if FOO is (1) a foreign key and (2) has a chooser.
-        See :term:`learning foreign key`.
+        See also :term:`learning foreign key`.
 
     """
 
@@ -128,11 +128,15 @@ class Model(models.Model, fields.TableRow):
 
     """
 
-
     allow_cascaded_delete = frozenset()
     """A set of names of `ForeignKey` or `GenericForeignKey` fields of
     this model that allow for cascaded delete.
 
+    Unlike with Dango's `on_delete
+    <https://docs.djangoproject.com/en/3.0/ref/models/fields/#django.db.models.ForeignKey.on_delete>`__
+    attribute you control cascaded delete behaviour on the model whose instances
+    are going to be deleted.
+
     If this is a simple string, Lino expects it to be a
     space-separated list of filenames and convert it into a set at
     startup.
@@ -151,10 +155,10 @@ class Model(models.Model, fields.TableRow):
     decide whether slaves of a record being duplicated should be
     duplicated as well.
 
-    A startup (in :meth:`kernel_startup
+    At startup (in :meth:`kernel_startup
     <lino.core.kernel.Kernel.kernel_startup>`) Lino automatically sets
     `on_delete
-    <https://docs.djangoproject.com/en/dev/ref/models/fields/#django.db.models.ForeignKey.on_delete>`_
+    <https://docs.djangoproject.com/en/3.0/ref/models/fields/#django.db.models.ForeignKey.on_delete>`__
     to ``PROTECT`` for all FK fields that are not listed in the
     ``allow_cascaded_delete`` of their model.
 
@@ -268,6 +272,11 @@ class Model(models.Model, fields.TableRow):
     """Whether to disable any automatic creation by learning choosers.
     """
 
+    summary_row_template = None
+    """
+    An optional name of a template to use for :meth:`as_summary_row`.
+    """
+
     _widget_options = {}
     _lino_tables = []
     _bleached_fields = []
@@ -477,6 +486,7 @@ class Model(models.Model, fields.TableRow):
         <lino_xl.lib.deploy.desktop.DeploymentsByTicket>`, :mod:`lino_book.projects.min3.lib.contacts`.
 
         """
+        # print("20200425", kwargs)
         return qs.filter(**kwargs)
         # if len(kwargs):
         #     raise Exception(
@@ -698,12 +708,6 @@ class Model(models.Model, fields.TableRow):
             ar.actor.after_create_instance(elem, ar)
         elem.after_ui_save(ar, None)
 
-    def save_existing_instance(self, ar):
-        watcher = ChangeWatcher(self)
-        ar.ah.store.form2obj(ar, ar.rqdata, self, False)
-        self.full_clean()
-        self.save_watched_instance(ar, watcher)
-
     def save_watched_instance(elem, ar, watcher):
         if watcher.is_dirty():
             pre_ui_save.send(sender=elem.__class__, instance=elem, ar=ar)
@@ -838,16 +842,37 @@ class Model(models.Model, fields.TableRow):
         """
         pass
 
+    def as_summary_row(self, ar):
+        """
+        Return a raw HTML string representing this object in a data view as a
+        single paragraph.
+
+        The string should represent a single ``<p>``.
+
+        If :attr:`summary_row_template` is set, this will render this object
+        using the named template, otherwise it will call :meth:`summary_row` and
+        wrap the result into a paragraph.
+
+
+        """
+        if self.summary_row_template:
+            # not tested
+            env = settings.SITE.plugins.jinja.renderer.jinja_env
+            template = env.get_template(self.summary_row_template)
+            context = ar.get_printable_context(obj=self)
+            return template.render(**context)
+        return tostring(E.p(*self.summary_row(ar)))
+
     def summary_row(self, ar, **kw):
         """
-        Return a HTML representation of this database object in a summary panel.
+        Yield a sequence of ElementTree elements that represent this database
+        object in a summary panel.
+
+        The elements will be wrapped into a `<p>` by :meth:`as_summary_row`.
 
         The default representation is the text returned by :meth:`__str__` in a
         link that opens the detail view on this database object.
 
-        More exactly this should return or yield a sequence of HTML element tree
-        elements.
-
         The description may vary depending on the given action request.
 
         For example a partner model of a given application may want to always
@@ -872,14 +897,14 @@ class Model(models.Model, fields.TableRow):
     def name_column(self, ar):
         return str(self)
 
-    @fields.displayfield(_("Description"))
-    def mobile_item(self, ar):
-        if ar is None:
-            return ''
-        return E.div(*forcetext(self.get_mobile_list_item_elems(ar)))
-
-    def get_mobile_list_item_elems(self, ar):
-        return [self.obj2href(ar)]
+    # @fields.displayfield(_("Description"))
+    # def mobile_item(self, ar):
+    #     if ar is None:
+    #         return ''
+    #     return E.div(*forcetext(self.get_mobile_list_item_elems(ar)))
+    #
+    # def get_mobile_list_item_elems(self, ar):
+    #     return [self.obj2href(ar)]
 
     # @fields.displayfield(_("Description"))
     # @fields.htmlbox(_("Overview"))
@@ -974,6 +999,8 @@ class Model(models.Model, fields.TableRow):
     @classmethod
     def get_chooser_for_field(cls, fieldname):
         d = getattr(cls, '_choosers_dict', {})
+        # if fieldname.endswith("__municipality"):
+        #     print("20200425 Model.get_chooser_for_field", cls, fieldname, d)
         return d.get(fieldname, None)
 
     @classmethod
@@ -1209,7 +1236,8 @@ LINO_MODEL_ATTRIBS = (
     'get_default_table',
     'get_layout_aliases',
     'get_actions_hotkeys',
-    # 'get_template_group',
+    'as_summary_row',
+    'summary_row_template',
     'get_related_project',
     'obj2href',
     'quick_search_fields',
