@@ -155,10 +155,15 @@ class Plugin(object):
 
     url_prefix = None
     """
-    The url prefix under which this app should ask to
+    The url prefix under which this plugin should ask to
     install its url patterns.
     """
 
+    force_url_prefix = False
+    """
+    Force lino to use the url_prefix, even if it's the default ui.
+    """
+
     site_js_snippets = []
     """
     List of js snippets to be injected into the `lino_*.js` file.
