@@ -415,7 +415,7 @@ class BaseRequest(object):
         from lino.core.actors import resolve_action
         if isinstance(spec, ActionRequest):  # deprecated use
             # raise Exception("20160627 Deprecated")
-            for k, v in list(kw.items()):
+            for k, v in kw.items():
                 assert hasattr(spec, k)
                 setattr(spec, k, v)
             spec.setup_from(self)
@@ -681,7 +681,6 @@ class BaseRequest(object):
         cb = self.add_callback(*msgs, uid=uid)
         cb.add_choice('yes', ok_func, gettext("Yes"))
         cb.add_choice('no', noop, gettext("No"))
-
         self.set_callback(cb)
 
         if not self.renderer.is_interactive:
@@ -961,7 +960,8 @@ class BaseRequest(object):
         then the city field is "obvious" and doesn't need to be displayed for
         each partner.
 
-        This is used e.g. in customized :meth:`summary_row` methods.
+        This is used e.g. in customized :meth:`lino.core.model.Model.summary_row`
+        :meth:`lino.core.model.Model.as_summary_row` methods.
 
         General rule: in a request on a slave table, the master instance is
         an obvious value.
@@ -1053,7 +1053,12 @@ class BaseRequest(object):
                     if ba.action.show_in_plain:
                         ir = ba.request_from(self)
                         if ir.get_permission():
-                            buttons.append(ir.ar2button(**btnattrs))
+                            # try:
+                            #     btn = ir.ar2button(**btnattrs)
+                            # except AttributeError:
+                            #     raise Exception("20200513 {}".format(ir))
+                            btn = ir.ar2button(**btnattrs)
+                            buttons.append(btn)
         # print("20181106", cls, self.bound_action, buttons)
         return buttons
         # if len(buttons) == 0:
@@ -1090,6 +1095,12 @@ class BaseRequest(object):
     def get_detail_title(self, elem):
         return self.actor.get_detail_title(self, elem)
 
+    def get_card_title(self, elem):
+        return self.actor.get_card_title(self, elem)
+
+    def get_main_card(self):
+        return self.actor.get_main_card(self)
+
     def as_button(self, *args, **kw):
         """Return a button which when activated executes (a copy of)
         this request.
@@ -1311,6 +1322,19 @@ class ActorRequest(BaseRequest):
         self._status = kw
         return kw
 
+    def clear_cached_status(self):
+        """Remove any previously computed status information.
+
+        The status information of a request is cached to avoid performance
+        issues e.g. in calendar views where a many buttons can be rendered for a
+        same request and where the status information can be relatively heavy.
+
+        But sometimes you don't want this. In that case you call
+        :meth:`clear_cached_status`.
+
+        """
+        self._status = None
+
     # def spawn(self, actor, **kw):
     #     """Same as :meth:`BaseRequest.spawn`, except that the first positional
     #     argument is an `actor`.
@@ -1355,7 +1379,7 @@ class ActorRequest(BaseRequest):
             # url = urlsplit(url)
             # url.scheme = settings.SITE.webdav_protocol
             # url = url.unsplit()
-        print("20180410 {}", url)
+        # print("20180410 {}", url)
         return url
 
     def pk2url(self, pk):
