@@ -49,7 +49,6 @@ from lino.utils import curry
 from lino.utils import iif
 from lino.utils.format_date import fds
 from lino.core.requests import PhantomRow
-from lino.core.gfks import GenericForeignKey, GenericRel
 from lino.utils import IncompleteDate
 
 
@@ -289,6 +288,10 @@ class ForeignKeyStoreField(RelatedMixin, ComboStoreField):
             # logger.info("20120109 %s -> %s -> %r",obj,self,v)
         if v is None:
             return (None, None)
+        elif v == constants.CHOICES_BLANK_FILTER_VALUE:
+            return (v, _("Blank"))
+        elif v == constants.CHOICES_NOT_BLANK_FILTER_VALUE:
+            return (v, _("Not Blank"))
         else:
             return (v.pk, self.format_value(ar, v))
             #return (v.pk, str(v))
@@ -477,6 +480,7 @@ class DisabledFieldsStoreField(SpecialStoreField):
     name = str('disabled_fields')
 
     def __init__(self, store):
+        from lino.core.gfks import GenericForeignKey
         SpecialStoreField.__init__(self, store)
         self.always_disabled = set()
         for f in self.store.all_fields:
@@ -612,10 +616,14 @@ class GenericForeignKeyField(DisplayStoreField):
             return ''
         if ar is None:
             return str(v)
-        if ar.renderer is None:
+        if getattr(ar, "renderer", None) is None:
             return str(v)
         return ar.obj2html(v)
 
+    def parse_form_value(self, v, obj):
+        v = getattr(obj, self.name, None)
+        return v
+
 class GenericRelField(RelatedMixin, DisplayStoreField):
 
     def full_value_from_object(self, obj, ar=None):
@@ -889,11 +897,12 @@ def create_atomizer(holder, fld, name):
         return OneToOneRelStoreField(fld, name)
 
     if settings.SITE.is_installed('contenttypes'):
+        from lino.core.gfks import GenericForeignKey, GenericRel
+        from lino.modlib.gfks.fields import GenericForeignKeyIdField
         if isinstance(fld, GenericForeignKey):
             return GenericForeignKeyField(fld, name)
         if isinstance(fld, GenericRel):
             return GenericRelField(fld, name)
-        from lino.modlib.gfks.fields import GenericForeignKeyIdField
         if isinstance(fld, GenericForeignKeyIdField):
             return ComboStoreField(fld, name)
 
@@ -940,11 +949,18 @@ class ParameterStore(BaseStore):
         self.param_fields = []
 
         holder = params_layout_handle.layout.get_chooser_holder()
+        # debug = False
         for pf in params_layout_handle._store_fields:
             sf = create_atomizer(holder, pf, pf.name)
             if sf is not None:
+                # if "__" in pf.name:
+                #     print("20200423 ParameterStore", pf.name, sf)
+                #     debug  = True
                 self.param_fields.append(sf)
 
+        # if debug:
+        #     print("20200423 ParameterStore2", self.param_fields)
+
         self.param_fields = tuple(self.param_fields)
         self.url_param = url_param
         self.params_layout_handle = params_layout_handle
@@ -954,14 +970,20 @@ class ParameterStore(BaseStore):
             self.__class__.__name__, self.params_layout_handle)
 
     def pv2dict(self, ar, pv, **d):
+        # debug = False
         for fld in self.param_fields:
+            #     debug = True
             v = pv.get(fld.name, None)
+            # if "__" in fld.name:
+            #     print("20200430", fld, v)
             fld.value2dict(ar, v, d, None)
             # try:
             #     v = pv.get(fld.name, None)
             #     fld.value2dict(ar, v, d, None)
             # except Exception as e:
             #     raise e.__class__("{} : {}".format(fld, e))
+        # if debug:
+        #     print("20200423", d)
         return d
 
     def pv2list(self, ar, pv, **d):  # new since 20140930
@@ -987,6 +1009,8 @@ class ParameterStore(BaseStore):
                 # can never be unset.  charfields have
                 # empty_strings_allowed e.g. id field may be empty.
                 # But don't do this for other cases.
+            elif form_value in (constants.CHOICES_BLANK_FILTER_VALUE, constants.CHOICES_NOT_BLANK_FILTER_VALUE):
+                return form_value
             else:
                 return sf.parse_form_value(form_value, None)
 
@@ -996,7 +1020,8 @@ class ParameterStore(BaseStore):
                     "%s expects a list of %d values but got %d: %s" % (
                         self, len(self.param_fields), len(pv), pv))
             for i, f in enumerate(self.param_fields):
-                kw[f.field.name] = parse(f, pv[i])
+                # kw[f.field.name] = parse(f, pv[i])
+                kw[f.name] = parse(f, pv[i])  # 20200423 support remote fields in parameters
         elif self.url_param == "fv":
             # try to get data from dict style in main body of request
             for i, f in enumerate(self.param_fields):
@@ -1026,6 +1051,8 @@ class Store(BaseStore):
         self.all_fields = []
         self.list_fields = []
         self.detail_fields = []
+        self.detail_fields = []
+        self.card_fields = []
         self.primary_keys = set([])
 
         def addfield(sf):
@@ -1046,6 +1073,11 @@ class Store(BaseStore):
             dh = form.get_layout_handle(settings.SITE.kernel.default_ui)
             self.collect_fields(self.detail_fields, dh)
 
+        form = rh.actor.card_layout
+        if form:
+            dh = form.get_layout_handle(settings.SITE.kernel.default_ui)
+            self.collect_fields(self.card_fields, dh)
+
         if self.pk is not None:
             self.pk_index = 0
             found = False
@@ -1096,6 +1128,7 @@ class Store(BaseStore):
         self.all_fields = tuple(self.all_fields)
         self.list_fields = tuple(self.list_fields)
         self.detail_fields = tuple(self.detail_fields)
+        self.card_fields = tuple(self.card_fields)
 
     def collect_fields(self, fields, *layouts):
         """`fields` is a pointer to either `self.detail_fields` or
