@@ -18,8 +18,8 @@ from django.utils.translation import ugettext_lazy as _
 from lino.core import actors
 from lino.core import actions
 from lino.core import fields
-from lino.core.tablerequest import TableRequest
 from lino.core.utils import resolve_fields_list
+from lino.core.tablerequest import TableRequest
 
 
 class InvalidRequest(Exception):
@@ -170,11 +170,11 @@ class AbstractTable(actors.Actor):
 
     """
 
-    column_names_m = None
-    """An optional alternative for :attr:`column_names` to use when
-    :attr:`mobile_view <lino.core.site.Site.mobile_view>` is True.
-
-    """
+    # column_names_m = None
+    # """An optional alternative for :attr:`column_names` to use when
+    # :attr:`mobile_view <lino.core.site.Site.mobile_view>` is True.
+    #
+    # """
 
     column_names = '*'
     """A string that describes the list of columns of this table.
@@ -399,11 +399,24 @@ class AbstractTable(actors.Actor):
     - `'grid'` (default) to render as a grid.
     - `'summary'` to render a summary in a HtmlBoxPanel.
     - `'html'` to render plain html a HtmlBoxPanel.
+    - `'cards'` to render a defined layout as a grid of cards (react only)
+    - `'list'` to render a defined layout as a list of cards (react only
 
     See :doc:`/dev/table_summaries`.
 
     """
 
+    max_render_depth = 2
+    """
+    Used to limit the rendering of slave card views. 
+    """
+
+    hide_if_empty = False
+    """
+    In a detail view if a slave table is empty, it's element will be hidden
+    """
+
+
     stay_in_grid = False
     """Set this to True if Lino should prefer grid mode and not open a
     detail window on a newly created record.  :class:`SubmitDetail
@@ -577,10 +590,11 @@ method in order to sort the rows of the queryset.
         :attr:`column_names` which depends on the request.
 
         """
-        if settings.SITE.mobile_view:
-            return self.column_names_m or self.column_names
-        else:
-            return self.column_names
+        # if settings.SITE.mobile_view:
+        #     return self.column_names_m or self.column_names
+        # else:
+        #     return self.column_names
+        return self.column_names
 
     @classmethod
     def group_from_row(self, row):
