@@ -5,7 +5,7 @@
 from __future__ import unicode_literals
 # from builtins import str
 
-from atelier.utils import isidentifier
+from lino.utils import isidentifier
 
 from lino.api import dd, _, pgettext
 
