@@ -8,7 +8,7 @@ Defines the :class:`ExtRenderer` class.
 
 import logging ; logger = logging.getLogger(__name__)
 
-import cgi
+from html import escape
 import time
 
 from django.conf import settings
@@ -364,9 +364,10 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
         d = dict(text=prepare_label(mi), handler=js_code(handler))
         if mi.bound_action and mi.bound_action.action.icon_name:
             d.update(iconCls='x-tbar-' + mi.bound_action.action.icon_name)
+        # if help_text:
+        #     d.update(tooltip=help_text, tooltipType='title')
+        # 20200429 seems that tooltipType 'title' doesn't work on menu items
         if settings.SITE.use_quicktips and help_text:
-            # d.update(tooltip=help_text)
-            # d.update(tooltipType='title')
             d.update(listeners=dict(render=js_code(
                 "Lino.quicktip_renderer(%s,%s)" % (
                     py2js('Foo'), py2js(help_text)))
@@ -461,7 +462,7 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
         """Build the "user menu", i.e. the menu in the top right corner.
         """
         if settings.SITE.user_model is not None:
-            if request.user.authenticated:
+            if request.user.is_authenticated:
                 if request.subst_user:
                     yield "Lino.set_subst_user(%s,%s);" % (
                         py2js(request.subst_user.id),
@@ -795,6 +796,7 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
         )
         if a.key:
             kw.update(keycode=a.key.keycode)
+
         if a.help_text:
             # if a.__class__.__name__ in ('ChangePassword', 'SubmitDetail'):
             #     logger.info("20160829 a2btn() %r %r", a, str(a.help_text))
@@ -802,16 +804,16 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
             # A tooltip becomes visible only on buttons with an
             # iconCls. On a button which has only text we must use
             # Lino.quicktip_renderer. But I didn't find out why this
-            # doesn't seem to work.
-            if a.icon_name:
-                kw.update(tooltip=a.help_text)
-            elif settings.SITE.use_quicktips:
-                kw.update(listeners=dict(render=js_code(
-                    "Lino.quicktip_renderer('a2btn',%s)" %
-                    py2js(a.help_text))
-                ))
+                # doesn't seem to work.
+            kw.update(tooltip=a.help_text, tooltipType='title')
+            # if not a.icon_name:
+            #     kw.update(tooltipType='title')
+            #    kw.update(listen   ers=dict(render=js_code(
+            #        "Lino.quicktip_renderer('a2btn',%s)" %
+            #        py2js(a.help_text))
+            #    ))
         elif a.icon_name:
-            kw.update(tooltip=a.get_label())
+            kw.update(tooltip=a.get_label(), tooltipType='title')
         return kw
 
     def build_on_render(self, main):
@@ -1186,7 +1188,7 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
             action.action.preprocessor)
         yield "  };"
         yield "  var panel = Ext.getCmp(rp);"
-        yield "  if(panel) panel.do_when_clean(true, h); else h();"
+        yield "  if(panel && !params.rqdata) panel.do_when_clean(true, h); else h();"
         yield "};"
 
     def js_render_window_action(self, rh, ba):
@@ -1282,7 +1284,7 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
 
         def fn():
             yield "// lino.js --- generated %s by %s for %s." % (
-                time.ctime(), cgi.escape(settings.SITE.site_version()),
+                time.ctime(), escape(settings.SITE.site_version()),
                 get_user_profile())
             # lino.__version__)
             #~ // $site.title ($lino.welcome_text())
