@@ -1,21 +1,25 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2014 Luc Saffre
+# Copyright 2008-2017 Luc Saffre
 # License: BSD (see file COPYING for details)
 
 """Defines the :class:`Language` model.
 
 """
+from builtins import object
 
 
 from django.db import models
 
-from lino import dd, mixins
+from lino.api import dd
+from lino import mixins
 from django.utils.translation import ugettext_lazy as _
 
+from lino.modlib.office.roles import OfficeStaff
+
 
 class Language(mixins.BabelNamed):
 
-    class Meta:
+    class Meta(object):
         verbose_name = _("Language")
         verbose_name_plural = _("Languages")
         ordering = ['name']
@@ -26,10 +30,6 @@ class Language(mixins.BabelNamed):
 
 class Languages(dd.Table):
     model = 'languages.Language'
-    required = dd.required(user_groups='office')
+    required_roles = dd.login_required(OfficeStaff)
 
 
-def setup_config_menu(site, ui, profile, m):
-    p = dd.plugins.languages.get_menu_group()
-    m = m.add_menu(p.app_label, p.verbose_name)
-    m.add_action('languages.Languages')
