@@ -14,11 +14,6 @@ TODO:
   which would be empty for # and @ but "]" for memo commands.
 
 """
-from __future__ import unicode_literals
-
-from builtins import str
-from builtins import object
-
 import logging ; logger = logging.getLogger(__name__)
 
 import re
@@ -133,9 +128,13 @@ class Parser(object):
             def fmt(x):
                 return x._defined_in
             ex = self.renderers[cl]
-            raise Exception(
-                "Duplicate renderer for {} : {} and {}".format(
-                    cl, fmt(ex), fmt(func)))
+            # raise Exception(
+            #     "Duplicate renderer for {} : {} and {}".format(
+            #         cl, fmt(ex), fmt(func)))
+            # logger.info("Ignore duplicate renderer for {} : {} and {}".format(
+            #        cl, fmt(ex), fmt(func)))
+            # Ignore silently
+            return
         self.renderers[cl] = func
 
     def register_django_model(
