@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2014 Luc Saffre
+# Copyright 2012-2014 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
 """
@@ -13,6 +13,6 @@ from django.conf import settings
 
 
 def objects():
-    for u in settings.SITE.user_model.objects.exclude(profile=''):
+    for u in settings.SITE.user_model.objects.exclude(user_type=''):
         u.set_password('1234')
         yield u
