@@ -13,12 +13,9 @@
 
 import sys
 
-PY2 = sys.version_info[0] == 2
-PY3 = sys.version_info[0] == 3
-
 SETUP_INFO = dict(
     name='lino',
-    version='20.4.1',
+    version='20.7.8',
     description="A framework for writing desktop-like web applications "
                 "using Django and ExtJS or React",
     license='BSD-2-Clause',
@@ -32,40 +29,31 @@ SETUP_INFO = dict(
 install_requires = [
     # 'Sphinx',
     'Django',
-    'atelier', 'unipath', 'python_dateutil', 'dateparser',
-    'etgen','docutils',
+    # 'atelier',
+    'unipath', 'python_dateutil', 'dateparser',
+    'etgen', # 'docutils',
     'Babel', 'lxml',
-    'beautifulsoup4',
     'odfpy',
-    # 'pisa',
     'jinja2', 'pytidylib', 'PyYAML',
     'clint',  # lino.modlib.checkdata.management.commands
     'django-localflavor',  # lino.modlib.sepa
-    # 'django-iban',  # lino.modlib.sepa
-    'openpyxl==3.0.1',
-     'html2text',
-    # 'cairocffi',  # 'cairocffi<0.7',
-    # 'bleach',
-    # 'html5lib',  # version 7x9 (not 9x9) required by bleach
-    # 'schedule==0.5.0',  # why a version restriction?
-    'schedule',
-    # 'django-wkhtmltopdf',
-    'beautifulsoup4',]
+    'django-click',  # for passwd command
+    'openpyxl',  # removed version requirement 'openpyxl==3.0.1',
+    'html2text',
+    'schedule']
 
-if PY2:
-    install_requires.append('reportlab<2.7')
-    install_requires.append('weasyprint<0.43')
-else:
-    install_requires.append('reportlab')
-    install_requires.append('weasyprint')
-    install_requires.append('zodb')
-    install_requires.append('DateTime')
-    # install_requires.append('appy@svn+https://svn.forge.pallavi.be/appy-dev/dev1')
-    # 'django-mailbox@git+https://github.com/cylonoven/django-mailbox#egg=django-mailbox'
-    # SETUP_INFO.update(dependency_links=[
-    #     "svn+https://svn.forge.pallavi.be/appy-dev/dev1#egg=appy-dev"
-        # "git+https://github.com/lino-framework/appypod.git@dbf123584cd9c5ef4a35e8efb9f489eaa54e26f2#egg=appy-dev"
-    # ])
+# install_requires.append('docutils')
+install_requires.append('beautifulsoup4')  # lino.modlib.memo.mixins
+# install_requires.append('reportlab')
+install_requires.append('weasyprint')
+# install_requires.append('zodb')
+install_requires.append('DateTime')
+# install_requires.append('appy@svn+https://svn.forge.pallavi.be/appy-dev/dev1')
+# 'django-mailbox@git+https://github.com/cylonoven/django-mailbox#egg=django-mailbox'
+# SETUP_INFO.update(dependency_links=[
+#     "svn+https://svn.forge.pallavi.be/appy-dev/dev1#egg=appy-dev"
+    # "git+https://github.com/lino-framework/appypod.git@dbf123584cd9c5ef4a35e8efb9f489eaa54e26f2#egg=appy-dev"
+# ])
 
 SETUP_INFO.update(install_requires=install_requires)
 
@@ -153,6 +141,8 @@ lino.modlib.gfks
 lino.modlib.gfks.fixtures
 lino.modlib.ipdict
 lino.modlib.jinja
+lino.modlib.jinja.management
+lino.modlib.jinja.management.commands
 lino.modlib.importfilters
 lino.modlib.languages
 lino.modlib.languages.fixtures
