@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2019 Rumma & Ko Ltd
+# Copyright 2009-2020 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
 """:mod:`lino.utils` (the top-level module) contains a few often-used
@@ -57,24 +57,205 @@ function for general use. It has also many subpackages and submodules.
 
 #~ import logging
 #~ logger = logging.getLogger(__name__)
-from builtins import str
 from past.utils import old_div
+from future.types import newstr
 import sys
 import datetime
+from dateutil.relativedelta import relativedelta
 import re
 from decimal import Decimal
 from collections import OrderedDict
+# import locale
 import dateparser
 
-# encapsulate where they come from:
-
-from atelier.utils import AttrDict, iif, ispure, assert_pure, confirm, isiterable, is_string, i2d, i2t
-from atelier import rstgen
+# import rstgen
 from etgen.utils import join_elems
 
 from lino.utils.cycler import Cycler
 from lino.utils.code import codefiles, codetime
 
+from rstgen.utils import confirm, i2d, i2t
+
+
+class AttrDict(dict):
+
+    """
+    Dictionary-like helper object.
+
+    Usage example:
+
+    >>> from lino.utils import AttrDict
+    >>> a = AttrDict()
+    >>> a.define('foo', 1)
+    >>> a.define('bar', 'baz', 2)
+    >>> a == {"bar": {"baz": 2}, "foo": 1}
+    True
+    >>> print(a.foo)
+    1
+    >>> print(a.bar.baz)
+    2
+    >>> print(a.resolve('bar.baz'))
+    2
+    >>> print(a.bar)
+    {'baz': 2}
+
+    """
+    def __getattr__(self, name):
+        try:
+            return self[name]
+        except KeyError:
+            raise AttributeError(
+                "AttrDict instance has no key '%s' (keys are %s)" % (
+                    name, ', '.join(list(self.keys()))))
+
+    def define2(self, name, value):
+        return self.define(*name.split('.') + [value])
+
+    def define(self, *args):
+        "args must be a series of names followed by the value"
+        assert len(args) >= 2
+        d = s = self
+        for n in args[:-2]:
+            d = s.get(n, None)
+            if d is None:
+                d = AttrDict()
+                s[n] = d
+            s = d
+        oldvalue = d.get(args[-2], None)
+        d[args[-2]] = args[-1]
+        return oldvalue
+
+    def resolve(self, name, default=None):
+        """
+        return an attribute with dotted name
+        """
+        o = self
+        for part in name.split('.'):
+            o = getattr(o, part, default)
+            # o = o.__getattr__(part)
+        return o
+
+
+def date_offset(ref, days=0, **offset):
+    """
+    Compute a date using a "reference date" and an offset.
+
+    >>> r = i2d(20140222)
+
+    In 10 days:
+    >>> date_offset(r, 10)
+    datetime.date(2014, 3, 4)
+
+    Four hundred days ago:
+    >>> date_offset(r, -400)
+    datetime.date(2013, 1, 18)
+
+
+    """
+    if days:
+        offset.update(days=days)
+    if offset:
+        return ref + datetime.timedelta(**offset)
+    return ref
+
+def iif(condition, true_value, false_value=None):
+    """
+    "Inline If" : an ``if`` statement as a function.
+
+    Examples:
+
+    >>> from lino.utils import iif
+    >>> print("Hello, %s world!" % iif(1+1==2, "real", "imaginary"))
+    Hello, real world!
+    >>> iif(True, "true")
+    'true'
+    >>> iif(False, "true")
+
+    """
+    if condition:
+        return true_value
+    return false_value
+
+
+def last_day_of_month(d):
+    """Return the last day of the month of the given date.
+
+    >>> from lino.utils import i2d
+    >>> last_day_of_month(i2d(20160212))
+    datetime.date(2016, 2, 29)
+    >>> last_day_of_month(i2d(20161201))
+    datetime.date(2016, 12, 31)
+    >>> last_day_of_month(i2d(20160123))
+    datetime.date(2016, 1, 31)
+    >>> last_day_of_month(i2d(20161123))
+    datetime.date(2016, 11, 30)
+
+    Thanks to `stackoverflow.com
+    <http://stackoverflow.com/questions/42950/get-last-day-of-the-month-in-python>`_.
+
+    """
+    return d + relativedelta(day=31)
+    # d = datetime.date(d.year, d.month + 1, 1)
+    # return relativedelta(d, days=-1)
+
+
+def isiterable(x):
+    "Returns `True` if the specified object is iterable."
+    try:
+        iter(x)
+    except TypeError:
+        return False
+    return True
+
+def is_string(s):
+    """Return True if the specified value is a string.
+    """
+    # if six.PY2:
+    #     return isinstance(s, six.string_types) or isinstance(s, newstr)
+    return isinstance(s, str)
+
+def isidentifier(s):
+    """
+    Check whether the given string can be used as a Python identifier.
+    """
+    # if six.PY2:
+    #     return re.match("[_A-Za-z][_a-zA-Z0-9]*$", s)
+    return s.isidentifier()
+
+
+def ispure(s):
+    """Returns `True` if the specified string `s` is either None, or
+    contains only ASCII characters, or is a validly encoded unicode
+    string.
+
+    """
+    if s is None:
+        return True
+    if isinstance(s, (str, newstr)):
+        return True
+    if type(s) == bytes:
+        try:
+            s.decode('ascii')
+        except UnicodeDecodeError:
+            return False
+        return True
+    return False
+
+
+def assert_pure(s):
+    """
+    raise an Exception if the given string is not :func:`ispure`.
+    """
+    #~ assert ispure(s), "%r: not pure" % s
+    if s is None:
+        return
+    if isinstance(s, str):
+        return True
+    try:
+        s.decode('ascii')
+    except UnicodeDecodeError as e:
+        raise Exception("%r is not pure : %s" % (s, e))
+
 def join_words(*words):
     """
     Remove any empty item (None or ''), call unicode on each and
