@@ -4,8 +4,8 @@
 """Some diagnostic utilities."""
 
 # from textwrap import fill
-from atelier import rstgen
-from atelier.utils import unindent
+import rstgen
+from rstgen.utils import unindent
 
 from django.conf import settings
 from django.db import models
